% This function returns the 4x4 homogenous coordinate expression for 
% precession for a particular gyromagnetic ratio (gamma), external 
% field (B0), and time step (dt).
%
% SYNTAX:  dB0=PAM_B0_op(gamma,B0,dt)
%
% INPUTS:  gamma - Gyromagnetic ratio [Hz/T]
%          B0    - Main magnetic field [T]
%          dt    - Time step or vector [s]
%
% OUTPUTS: dB0   - Precessional operator [4x4]
%
% DBE@UCLA 01.21.2015

function dB0=PAM_B0_op(gamma,B0,dt)

if nargin==0
  gamma=42.57e6;        % Gyromagnetic ratio for 1H
  B0=1.5;               % Typical B0 field strength
  dt=ones(1,100)*1e-6;  % 100 1s time steps 
end

dB0=zeros(4,4,numel(dt));  % Initialize the array

for n=1:numel(dt)
  dw=2*pi*gamma*B0*dt(n);  % Incremental precession (rotation angle)
  
  % Precessional Operator (left handed)
  dB0(:,:,n)=[ cos(dw)  sin(dw)   0  0;
              -sin(dw)  cos(dw)   0  0;
                0         0       1  0;
                0         0       0  1];
  
end
return